/**
* Este arquivo funciona em conjunto com a biblioteca Zend_Gdata (posicionada em C:\xampp\php\ZendGdata-1.11.10\library).  necessrio
* configurar o arquivo php.ini, adicionando a localizao da biblioteca Zend_Gdata ao parmetro "include_path". Na rea relativa a extenes 
* do arquivo php.ini, deve ser adicionada (caso no houver) a linha: extension=php_openssl.dll
* Tambm so necessrios os arquivos 'video_browser.js', 'index.php', 'video_browser.css' e 'extrai_script.js' (para executar cdigo Javascript
* retornado atravs de Ajax. Sem isso, cdigos Javascript em contedo inserido por Ajax no so executados, visto que Javascript  executado
* no carregamento da pgina - quando o Ajax  executado, a pgina j foi carregada, por isso contedos Javascript inseridos via Ajax no so executados,
* a no ser utilizando essa funo chamada extrai_script.js) .
* A chamada para a listagem dos vdeos comea no evento onload da tag body do arquivo de interface (interface.html). Nesse momento  
* executada a funo Javascript ytvbp.listVideos(autor, pgina), onde se deve passar como parmetros o autor do canal do Youtube e a 
* pgina da paginao a ser exibida primeiro, entretanto, pode-se chamar a funo ytvbp.listVideos passando apenas o autor (nesse caso, o
* parmetro "pgina"  automaticamente definido como sendo igual a 1). Por fim, o arquivo 'video_browser.js' se comunica com o arquivo 
* 'index.php', que faz uso da biblioteca  Zend_Gdata para obter listas de vdeo do Youtube. O arquivo 'index.php' devolve o resultado da busca 
* para o arquivo 'video_browser.js' e este ltimo injeta o contedo no arquivo de interface (interface.html) atravs de Ajax.  O arquivo video 
* 'video_browser.css' serve para posicionar e tratar visualmente os elementos retornados. Para tudo isso funcionar, 
*  preciso ter PHP >= 5.1.4

Este arquivo foi adaptado para funcionar no site: http://www.andrefigueiredo.net/
 */

/**
 * @fileoverview Provides functions for browsing and searching YouTube 
 * data API feeds using a PHP backend powered by the Zend_Gdata component
 * of the Zend Framework.
 */

/**
 * provides namespacing for the YouTube Video Browser PHP version (ytvbp)
 */
var ytvbp = {};

/** 
 * maximum number of results to return for list of videos
 * @type Number
 */
ytvbp.MAX_RESULTS_LIST = 10;

/**
 * navigation button id used to page to the previous page of
 * results in the list of videos
 * @type String
 */
ytvbp.PREVIOUS_PAGE_BUTTON = 'previousPageButton';

/**
 * navigation button id used to page to the next page of
 * results in the list of videos
 * @type String
 */
ytvbp.NEXT_PAGE_BUTTON = 'nextPageButton';

/**
 * container div id used to hold list of videos
 * @type String
 */
ytvbp.VIDEO_LIST_CONTAINER_DIV = 'searchResultsVideoList';

/**
 * container div id used to hold the video player
 * @type String
 */
ytvbp.VIDEO_PLAYER_DIV = 'videoPlayer';

/**
 * the page number to use for the next page navigation button
 * @type Number
 */
ytvbp.nextPage = 2;

/**
 * the page number to use for the previous page navigation button
 * @type Number
 */
ytvbp.previousPage = 0;

/**
 * the author of video feed used for querying - allows for the navigation
 * buttons to know what type of query to perform when clicked
 *  The value of ytvbp.author changes when the first query is executed
 * @type String
 */
ytvbp.author = '';

/**
the page that will be showed of the pagination. For instance, if the pagination has 3 pages
* and the page's parameter is 2, the result will start showing by the second page. If you
* want to see the first page, you need to press the previous button. The standard value of 
* the page's parameter is 1 (it starts showing by the first page)
*/
ytvbp.page = 1;

/**
 * Retrieves a list of videos matching the provided criteria.  The list of
 * videos can be restricted to a particular author feed.
 * @param {String} author The author of the video feed  
 * @param {Number} page The 1-based page of results to return. If page is undefined, the value assumed is ytvbp.page
 */
ytvbp.listVideos = function(author, page) {
  // If page is undefined, the value assumed is ytvbp.page
  if(typeof  page == 'undefined'){
	page = ytvbp.page;	
  }  
  // The value of the variable named "author" is put into the variable "ytvbp.author" for the use of navigation buttons
  ytvbp.author = author;
  var maxResults = ytvbp.MAX_RESULTS_LIST;
  var startIndex =  (((page - 1) * ytvbp.MAX_RESULTS_LIST) + 1);
  ytvbp.presentFeed(author, maxResults, startIndex);  
  ytvbp.updateNavigation(page);
};

/**
 * Sends an AJAX request to the server to retrieve a list of videos or
 * the video player/metadata.  Sends the request to the specified filePath
 * on the same host, passing the specified params, and filling the specified
 * resultDivName with the resutls upon success.
 * @param {String} filePath The path to which the request should be sent
 * @param {String} params The URL encoded POST params
 * @param {String} resultDivName The name of the DIV used to hold the results
 */
ytvbp.sendRequest = function(filePath, params, resultDivName) {
  if (window.XMLHttpRequest) {
    var xmlhr = new XMLHttpRequest();
  } else {
    var xmlhr = new ActiveXObject('MSXML2.XMLHTTP.3.0');
  }
  
  xmlhr.open('POST', filePath, true);
  xmlhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded'); 

  xmlhr.onreadystatechange = function() {
    var resultDiv = document.getElementById(resultDivName);
    if (xmlhr.readyState == 1) {
      resultDiv.innerHTML = '<b>Carregando...</b>';
    } else if (xmlhr.readyState == 4 && xmlhr.status == 200) {
      if (xmlhr.responseText) {
        resultDiv.innerHTML = xmlhr.responseText;
		var codigo = xmlhr.responseText;
		// Funo para executar qualquer funo Javascript que estiver no contedo retornado atravs de AJAX		
		extraiScript(codigo);
      }
    } else if (xmlhr.readyState == 4) {
      alert('Invalid response received - Status: ' + xmlhr.status);
    }
  }  
  xmlhr.send(params);  
}

/**
 * Uses ytvbp.sendRequest to display a YT video player and metadata for the
 * specified video ID.
 * @param {String} videoId The ID of the YouTube video to show
 */
ytvbp.presentVideo = function(videoId) {  
  var params = 'videoId=' + videoId;
  var filePath = 'youtube_playlists/index.php';
  ytvbp.sendRequest(filePath, params, ytvbp.VIDEO_PLAYER_DIV);
}

/**
 * Uses ytvbp.sendRequest to display a list of of YT videos.
 * @param {String} author The author of the video feed
 * @param {Number} maxResults The maximum number of videos to list
 * @param {Number} startIndex The first video to include in the list 
 */
ytvbp.presentFeed = function(author, maxResults, startIndex){
  var params = 'author=' + author + 
               '&maxResults=' + maxResults +
               '&startIndex=' + startIndex; 
  var filePath = 'youtube_playlists/index.php';
  ytvbp.sendRequest(filePath, params, ytvbp.VIDEO_LIST_CONTAINER_DIV);
}

/**
 * Updates the variables used by the navigation buttons and the 'enabled' 
 * status of the buttons based upon the current page number passed in.
 * @param {Number} page The current page number
 */
ytvbp.updateNavigation = function(page) {
  ytvbp.nextPage = page + 1;
  ytvbp.previousPage = page - 1;
  document.getElementById(ytvbp.NEXT_PAGE_BUTTON).style.display = 'inline';
  document.getElementById(ytvbp.PREVIOUS_PAGE_BUTTON).style.display = 'inline';
  if (ytvbp.previousPage < 1) {
    document.getElementById(ytvbp.PREVIOUS_PAGE_BUTTON).disabled = true;
  } else {
    document.getElementById(ytvbp.PREVIOUS_PAGE_BUTTON).disabled = false;  
  }  
};